RobotsDirective

Struct RobotsDirective 

pub struct RobotsDirective { /* private fields */ }
A robots directive set suitable for meta content formatting.

Implementations

Source

impl RobotsDirective

pub const fn new(index: IndexDirective, follow: FollowDirective) -> Self

Creates a robots directive from index and follow directives.

pub const fn index_follow() -> Self

Common index,follow directive.

pub const fn noindex_nofollow() -> Self

Common noindex,nofollow directive.

pub const fn with_snippet(self, snippet: SnippetDirective) -> Self

Sets the snippet directive.

pub const fn with_archive(self, archive: ArchiveDirective) -> Self

Sets the archive directive.

pub const fn index(&self) -> IndexDirective

Returns the index directive.

pub const fn follow(&self) -> FollowDirective

Returns the follow directive.

pub fn to_meta_content(&self) -> String

Formats this directive as a robots meta content value.