pub struct RobotsDirective { /* private fields */ }Expand description
A robots directive set suitable for meta content formatting.
Implementations
Sourceimpl RobotsDirective
impl RobotsDirective
Sourcepub const fn new(index: IndexDirective, follow: FollowDirective) -> Self
pub const fn new(index: IndexDirective, follow: FollowDirective) -> Self
Creates a robots directive from index and follow directives.
Sourcepub const fn index_follow() -> Self
pub const fn index_follow() -> Self
Common index,follow directive.
Sourcepub const fn noindex_nofollow() -> Self
pub const fn noindex_nofollow() -> Self
Common noindex,nofollow directive.
Sourcepub const fn with_snippet(self, snippet: SnippetDirective) -> Self
pub const fn with_snippet(self, snippet: SnippetDirective) -> Self
Sets the snippet directive.
Sourcepub const fn with_archive(self, archive: ArchiveDirective) -> Self
pub const fn with_archive(self, archive: ArchiveDirective) -> Self
Sets the archive directive.
Sourcepub const fn index(&self) -> IndexDirective
pub const fn index(&self) -> IndexDirective
Returns the index directive.
Sourcepub const fn follow(&self) -> FollowDirective
pub const fn follow(&self) -> FollowDirective
Returns the follow directive.
Sourcepub fn to_meta_content(&self) -> String
pub fn to_meta_content(&self) -> String
Formats this directive as a robots meta content value.